// VinciaMatching.h is a part of the VINCIA plug-in to the PYTHIA 8 generator.
// Copyright (C) 2010 W.T. Giele, D.A. Kosower, P.Z. Skands.
// VINCIA is licenced under the GNU GPL version 2.
// Please respect the MCnet Guidelines for Event Generator Authors and Users, 
//               http://www.montecarlonet.org/GUIDELINES

// This file contains header information for VINCIA's Matching class.
  
#ifndef VINCIAEVOLVARS_H
#define VINCIAEVOLVARS_H

#include "Basics.h"                   // Vec4
#include "Event.h"                    // Particle
#include "VinciaCommon.h"             // m2, printOut, etc.

using namespace Pythia8;

namespace Vincia {

  class EvolutionVariable {
    
  public:
    
    // Constructor.
    EvolutionVariable() {isInitPtr=false, isInit=false;};

    // Destructor.
    virtual ~EvolutionVariable() {};

    // Initialize Pointers (must be done before init)
    void initPtr(Settings* settingsPtrIn) {
      settingsPtr    = settingsPtrIn; 
      isInitPtr=true;
    }
    
    bool init() {
      // Check that pointers initialized
      if (! isInitPtr) {
	printOut("Antenna::init","Cannot initialize, pointers not set.");
	return false;
      }
      // Set verbose level
      verbose = settingsPtr->mode("Vincia:verbose");
      isInit  = true;
      return isInit;
    }

    // Ordering variable (dimensionless)
    double yE(double,double,int typeIn=0);  //yE(y12,y23,EvolutionType)
    double yE(double*,double*,double*, int typeIn=0);//yE(p1,p2,p3,EvolutionType)
    double yE(Vec4,Vec4,Vec4, int typeIn=0);//yE(p1,p2,p3,EvolutionType)
    
    // Ordering variable (dimensionful)
    double Q2E(double, double, double, int typeIn=0); 
    double Q2E(Vec4, Vec4, Vec4, int typeIn=0); 
    double Q2E(Particle, Particle, Particle, int typeIn=0); 
 
    // Set verbose level
    void setVerbose(int verboseIn) {verbose = verboseIn;}

  private:

    // Is initialized?
    bool isInitPtr, isInit;
   
    // Pointer to PYTHIA 8 Settings database
    Settings* settingsPtr;

    // Verbose level
    int verbose;

  };

}

#endif
